@@ -1,34 +1,23 @@
 #
-# Copyright 2008-2014 Universidad Complutense de Madrid
+# Copyright 2008-2018 Universidad Complutense de Madrid
 #
 # This file is part of Numina
 #
-# Numina is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# Numina is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Numina.  If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0+
+# License-Filename: LICENSE.txt
 #
 
 
-'''Extra logging handlers for the numina logging system.'''
+"""Extra logging handlers for the numina logging system."""
+
 
 import logging
 
 from astropy.io import fits
 
-from numina.core import DataFrame
-
 
 class FITSHistoryHandler(logging.Handler):
-    '''Logging handler using HISTORY FITS cards'''
+    """Logging handler using HISTORY FITS cards"""
     def __init__(self, header):
         logging.Handler.__init__(self)
         self.header = header
@@ -39,7 +28,7 @@ class FITSHistoryHandler(logging.Handler):
 
 
 def log_to_history(logger, name):
-    '''Decorate function, adding a logger handler stored in FITS.'''
+    """Decorate function, adding a logger handler stored in FITS."""
 
     def log_to_history_decorator(method):
 
