@@ -19,7 +19,7 @@
  */
 
 #include <memory>
-#include <ext/functional>
+#include <functional>
 #include <cmath>
 
 #include "nu_combine_defs.h"
@@ -29,8 +29,10 @@
 
 using Numina::ZipIterator;
 using Numina::make_zip_iterator;
-using Numina::compose;
+using Numina::LessPair1st;
+using Numina::RangePair1st;
 using Numina::average_central_tendency;
+using Numina::sum_central_tendency;
 using Numina::average_central_tendency_clip;
 using Numina::median_central_tendency;
 
@@ -51,6 +53,17 @@ int NU_mean_function(double *data, double *weights,
   return 1;
 }
 
+int NU_sum_function(double *data, double *weights,
+    size_t size, double *out[NU_COMBINE_OUTDIM], void *func_data)
+{
+  *out[2] = size;
+  ValuePair r = sum_central_tendency(data, data + size, weights);
+  *out[0] = r.first;
+  *out[1] = r.second;
+
+  return 1;
+}
+
 int NU_median_function(double *data, double *weights,
     size_t size, double *out[NU_COMBINE_OUTDIM], void *func_data)
 {
@@ -90,12 +103,8 @@ int NU_minmax_function(double *data, double *weights,
 
   ZIterPair result = reject_min_max(make_zip_iterator(data, weights),
       make_zip_iterator(data + size, weights + size), nmin, nmax,
-      // Compares two std::pair objects. Returns true
-      // if the first component of the first is less than the first component
-      // of the second std::pair
-      compose(std::less<double>(), __gnu_cxx::select1st<
-          ZIter::value_type>(), __gnu_cxx::select1st<
-          ZIter::value_type>()));
+      LessPair1st<typename ZIter::value_type, typename ZIter::value_type>()
+  );
 
   *out[2] = result.second - result.first;
   IterPair beg = result.first.get_iterator_pair();
@@ -130,19 +139,7 @@ int NU_sigmaclip_function(double *data, double *weights,
 
       const double low = c_mean - c_std * slow;
       const double high = c_mean + c_std * shigh;
-      ned = partition(beg, ned,
-          // Checks if first component of a std::pair
-          // is inside the range (low, high)
-          // equivalent to return (low < x.first) && (high > x.first);
-          __gnu_cxx::compose2(std::logical_and<bool>(),
-              __gnu_cxx::compose1(
-                  std::bind1st(std::less<double>(), low),
-                  __gnu_cxx::select1st<ZIter::value_type>()),
-              __gnu_cxx::compose1(
-                  std::bind1st(std::greater<double>(), high),
-                  __gnu_cxx::select1st<ZIter::value_type>())
-            )
-          );
+      ned = partition(beg, ned, RangePair1st<ZIter::value_type>(low, high));
 
       nc_size = std::distance(beg, ned);
       // We stop when std == 0, all the points would be reject otherwise
@@ -165,15 +162,15 @@ int NU_quantileclip_function(double *data, double *weights,
   size_t nclip = static_cast<size_t>(floor(n_elem_to_clip));
   size_t mclip = static_cast<size_t>(ceil(n_elem_to_clip));
 
-  if (size - 2 * mclip <= 0) {
+  if (size - mclip - mclip <= 0) {
     // We reject more points that we have locally
     *out[0] = 0.0;
     *out[1] = 0.0;
-    *out[2] = size - 2 * mclip;
+    *out[2] = size - mclip - mclip;
     return 1;
   }
 
-  *out[2] = size - 2 * n_elem_to_clip;
+  *out[2] = size - nclip - mclip;
 
   if (nclip == mclip) {
     // No interpolation
@@ -185,8 +182,8 @@ int NU_quantileclip_function(double *data, double *weights,
     // Interpolation
     ValuePair r1 = average_central_tendency_clip(data, data + size, weights, nclip, nclip);
     ValuePair r2 = average_central_tendency_clip(data, data + size, weights, mclip, mclip);
-    *out[0] = r1.first + (n_elem_to_clip - nclip) * (r2.first - r1.first);
-    *out[1] = r1.second + (n_elem_to_clip - nclip) * (r2.second - r1.second);
+    *out[0] = r1.first + mclip * (r2.first - r1.first);
+    *out[1] = r1.second + mclip * (r2.second - r1.second);
   }
 
   return 1;
